@@ -1248,7 +1248,7 @@ command."
   "Get the value of FIELD, searching up to buffer position MAX.
 See `search-forward-regexp'."
   (save-excursion
-    (ignore-errors
+    (condition-case nil
       (let ((str
              (progn
                (goto-char (point-min))
@@ -1272,7 +1272,8 @@ See `search-forward-regexp'."
                     (concat start-string end-string)
                   ;; Leave as is.
                   str)))
-          str)))))
+          str))
+      (error nil))))
 
 (defun rpm-find-spec-version (&optional with-epoch)
   "Get the version string.
